==> drumgizmo-0.9.6.tar.gz: drumgizmo-0.9.6/lv2/lv2_instance.h <==
/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/***************************************************************************
 *            lv2_instance.h
 *
 *  Sun Nov 20 15:27:41 CET 2011
 *  Copyright 2011 Bent Bisballe Nyeng
 *  deva@aasimon.org
 ****************************************************************************/

/*
 *  This file is part of DrumGizmo.
 *
 *  DrumGizmo is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  DrumGizmo is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with DrumGizmo; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.
 */
#ifndef __DRUMGIZMO_LV2_INSTANCE_H__
#define __DRUMGIZMO_LV2_INSTANCE_H__

#include <lv2/lv2plug.in/ns/lv2core/lv2.h>
#include <lv2/lv2plug.in/ns/ext/state/state.h>
#include <lv2/lv2plug.in/ns/ext/uri-map/uri-map.h>

#include "input_lv2.h"
#include "output_lv2.h"

#include <drumgizmo.h>

typedef struct {
  InputLV2 *in;
  OutputLV2 *out;
  DrumGizmo *dg;
  sample_t *buffer;
  size_t buffer_size;
  LV2_URI_Map_Feature *urimap;
  LV2_State_Make_Path *makepath;
} DGLV2;

#endif/*__DRUMGIZMO_LV2_INSTANCE_H__*/

==> drumgizmo-0.9.8.tar.gz: drumgizmo-0.9.8/lv2/lv2_instance.h <==
/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/***************************************************************************
 *            lv2_instance.h
 *
 *  Sun Nov 20 15:27:41 CET 2011
 *  Copyright 2011 Bent Bisballe Nyeng
 *  deva@aasimon.org
 ****************************************************************************/

/*
 *  This file is part of DrumGizmo.
 *
 *  DrumGizmo is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  DrumGizmo is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with DrumGizmo; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.
 */
#ifndef __DRUMGIZMO_LV2_INSTANCE_H__
#define __DRUMGIZMO_LV2_INSTANCE_H__

#include <lv2/lv2plug.in/ns/lv2core/lv2.h>
#include <lv2/lv2plug.in/ns/ext/state/state.h>
#include <lv2/lv2plug.in/ns/ext/urid/urid.h>

#include "input_lv2.h"
#include "output_lv2.h"

#include <drumgizmo.h>

typedef struct {
  InputLV2 *in;
  OutputLV2 *out;
  DrumGizmo *dg;
  sample_t *buffer;
  size_t buffer_size;
  LV2_URID_Map* map;
} DGLV2;

#endif/*__DRUMGIZMO_LV2_INSTANCE_H__*/
